function aliasing(f,fm,tmax)
% Demostracion del fenomeno aliasing utilizando señales senoidales
% [] = aliasing(f,fm,tmax)
% 
% 
% f:    frecuencia de la señal
% fm:   frecuencia de muestreo
% tmax: rango en segundos mostrado en pantalla

fmcont = inv(tmax/1000);
t = 0:inv(fmcont):tmax;
tk= 0:inv(fm):tmax;

figure(1);
plot(t,sin(2*pi*f*t));
hold on;
plot(tk,sin(2*pi*f*tk),'ro-');
hold off;
axis([0 tmax -1.2 1.2]);
grid on;

title(strcat('fm=', num2str(fm), ' f=', num2str(f)));
drawnow;




